@@ -78,7 +78,7 @@ widget got found.
     This more complete example is also demonstrating
     the implementation and usage of the help activator
     and layout widgets (in the classes
-    :class:`~ae.kivy_help.HelpBehaviour`,
+    :class:`~ae.kivy_help.HelpBehavior`,
     :class:`~ae.kivy_help.HelpToggler` and
     :class:`~ae.kivy_help.HelpLayout`).
 
@@ -234,7 +234,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.10'
+__version__ = '0.1.11'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
